@@ -24,10 +24,10 @@ def get_game_window_information() -> list:
     return info_dict_list
 
 
-def get_game_window_handle(title_pattern: str = None) -> list:
+def get_game_window_handle(title_pattern: str = r'.*') -> list:
     """
     获取所有游戏窗口句柄
-    :param: 窗口标题匹配模式字符串
+    :param: 窗口标题匹配模式字符串，默认所有
     :return: 由游戏窗口句柄组成的列表
     """
     def get_all_child_window(parent):
